@@ -299,7 +299,7 @@ def create_kfold_datasets_file(args, api, command_obj, resume=False):
     message = ('Creating the kfold datasets............\n')
     u.log_message(message, log_file=session_file, console=args.verbosity)
     if args.output_dir is None:
-        args.output_dir = a.NOW
+        args.output_dir = a.OUTPUT_DIR
 
     csv_properties = {}
     fields = None
@@ -327,6 +327,8 @@ def create_kfold_datasets_file(args, api, command_obj, resume=False):
         if not dataset:
             dataset = api.check_resource(dataset_id,
                                          query_string=ALL_FIELDS_QS)
+            if args.name is None:
+                args.name = dataset["object"]["name"]
         try:
             args.objective_field = int(args.objective_field)
         except (TypeError, ValueError):
