@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2021 BigML
+# Copyright 2012-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -207,6 +207,7 @@ FLAGS = {
         {'flag': 'score', 'type': 'boolean'},
         {'flag': 'anomalies-dataset', 'type': 'string'},
         {'flag': 'top_n', 'type': 'int'},
+        {'flag': 'id_fields', 'type': 'string'},
         {'flag': 'forest_size', 'type': 'int'}],
     'BigMLer sample': [
         {'flag': 'anomaly_fields', 'type': 'string'},
@@ -328,6 +329,8 @@ FLAGS = {
         {'flag': 'missing_numerics', 'type': 'boolean'},
         {'flag': 'no_missing_numerics', 'type': 'boolean'},
         {'flag': 'tree_embedding', 'type': 'boolean'},
+        {'flag': 'image_augmentations', 'type': 'string'},
+        {'flag': 'include_extracted_features', 'type': 'string'},
         {'flag': 'no_balance_fields', 'type': 'boolean'},
         {'flag': 'deepnet_attributes', 'type': 'string'}],
     'BigMLer execute': [
