@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2020-2021 BigML
+# Copyright 2020-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -52,7 +52,8 @@ def set_anomaly_args(args, name=None, fields=None, anomaly_fields=None):
     if anomaly_fields and fields is not None:
         input_fields = configure_input_fields(fields, anomaly_fields)
         anomaly_args.update(input_fields=input_fields)
-
+    if args.id_fields is not None:
+        anomaly_args.update({"id_fields": args.id_fields_})
     if args.top_n > 0:
         anomaly_args.update(top_n=args.top_n)
     if args.forest_size > 0:
