@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2021 BigML
+# Copyright 2014-2022 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,6 +18,7 @@
 
 import os
 import time
+
 try:
     import simplejson as json
 except ImportError:
@@ -184,18 +185,24 @@ def i_create_proportional_to_evaluate(step, test=None):
 
 #@step(r'the evaluation file is like "(.*)"$')
 def then_the_evaluation_file_is_like(step, check_file_json):
-    check_file_json = res_filename(check_file_json)
+    check_file_path = res_filename(check_file_json)
     evaluation_file_json = world.output + ".json"
     try:
         evaluation_file_json = open(evaluation_file_json, "U")
-        check_file_json = open(check_file_json, "U")
+        check_file_json = open(check_file_path, "U")
         check = check_file_json.readline()
         evaluation = evaluation_file_json.readline()
         check = json.loads(check)
         evaluation = json.loads(evaluation)
         if 'model' in check:
-            assert_equal(check['model'], evaluation['model'])
-            assert_equal(check['mode'], evaluation['mode'])
+            for metric, value in check['model'].items():
+                if not isinstance(value, list) and not isinstance(value, dict):
+                    assert_equal(
+                        check['model'][metric], evaluation['model'][metric],
+                        "model %s" % metric)
+                    assert_equal(
+                        check['mode'][metric], evaluation['mode'][metric],
+                        "mode %s" % metric)
         else:
             del check["datasets"]
             del evaluation["datasets"]
@@ -203,6 +210,8 @@ def then_the_evaluation_file_is_like(step, check_file_json):
         evaluation_file_json.close()
         check_file_json.close()
     except Exception as exc:
+        with open("%s.new" % check_file_path, "w") as eval_handler:
+            json.dump(evaluation, eval_handler)
         assert False, str(exc)
 
 #@step(r'I check that the (.*) dataset has been created$')
